import ActionAlert from "./ActionAlert";
import ActionModal from "./ActionModal";
/**
 * Actions.
 *
 * @since 1.0.0
 */
export default class Actions {
    actions = [];
    /**
     * Constructor.
     *
     * @param form Form instance.
     * @param actionsData Actions data.
     *
     * @since 1.0.0
     */
    constructor(actionsData) {
        actionsData.forEach(actionData => {
            switch (actionData.type) {
                case "alert":
                    this.actions.push(new ActionAlert(actionData.data));
                    break;
                case "modal":
                    this.actions.push(new ActionModal(actionData.data));
                    break;
                default:
                    throw new Error("Action type '" + actionData.type + "' does not exist.");
            }
        });
    }
    /**
     * Run all actions.
     *
     * @since 1.0.0
     */
    run() {
        this.actions.forEach(action => action.run());
    }
}
