import CSSClasses from '../CSSClasses';
import Conditions from '../Helpers/Conditions';
import MultipleField from './MultipleField';
import SingleField from './SingleField';
/**
 * Class Fieldset.
 *
 * @since 1.0.0
 */
export default class Fieldset {
    id;
    label;
    fields = [];
    nextFieldset;
    prevFieldset;
    conditions;
    classes;
    /**
     * Constructor.
     *
     * @param form Form object.
     *
     * @since 1.0.0
     */
    constructor(fieldsetData, formValues = []) {
        this.id = fieldsetData.id;
        this.label = fieldsetData.label;
        this.nextFieldset = fieldsetData.nextFieldset;
        this.prevFieldset = fieldsetData.prevFieldset;
        fieldsetData.fields.forEach((fieldData) => {
            if (fieldData.multiple === true) {
                this.fields.push(new MultipleField(fieldData, formValues));
            }
            else {
                this.fields.push(new SingleField(fieldData, formValues));
            }
        });
        this.conditions = new Conditions(fieldsetData.conditions, formValues);
        this.classes = new CSSClasses(fieldsetData.classes);
    }
    hasNext() {
        return this.nextFieldset !== undefined;
    }
    hasPrev() {
        return this.prevFieldset !== undefined;
    }
}
