/**
 * Dynamic value class.
 *
 * @since 1.0.0
 */
export default class DynamicValue {
    formValues;
    valueFieldId;
    valueDefault;
    valueCallback;
    /**
     * Constructor.
     *
     * @param value Value of the field.
     * @param valueFieldId Value from another field.
     * @param valueDefault Default value.
     * @param valueCallback Callback function to get value.
     */
    constructor(formValues, valueFieldId, valueDefault, valueCallback) {
        this.formValues = formValues;
        this.valueFieldId = valueFieldId;
        this.valueDefault = valueDefault;
        this.valueCallback = valueCallback;
    }
    /**
     * Get value
     *
     * @param form Form object.
     * @param type Type of dynamic value.
     *
     * @since 1.0.0
     */
    get() {
        // 2nd take default value.
        if (this.valueDefault !== undefined) {
            return this.valueDefault;
        }
        // 3nd take value from a specific field.
        if (this.valueFieldId !== undefined) {
            let value = this.formValues[this.valueFieldId];
            if (value !== undefined) {
                return value;
            }
        }
        // We need the callback here!
    }
}
